@@ -10,7 +10,7 @@
 
 """Python compatibility module."""
 
-from __future__ import absolute_import, unicode_literals, print_function
+from __future__ import absolute_import, print_function
 
 # Python 2/3 compatibility
 try:
